@@ -1,16 +1,10 @@
-import copy
-import os
-import os.path as osp
-from collections import deque
-
 import numpy as np
-import torch
-import torch.nn.functional as F
-from drone_tracker.trackers.bytetrack import matching
-from drone_tracker.trackers.bytetrack.basetrack import BaseTrack, TrackState
-from drone_tracker.trackers.bytetrack.kalman_filter import KalmanFilter
 from yolov5.utils.general import xywh2xyxy, xyxy2xywh
 
+from bytetracker import matching
+from bytetracker.basetrack import BaseTrack, TrackState
+from bytetracker.kalman_filter import KalmanFilter
+
 
 class STrack(BaseTrack):
     shared_kalman = KalmanFilter()
@@ -18,7 +12,7 @@ class STrack(BaseTrack):
     def __init__(self, tlwh, score, cls):
 
         # wait activate
-        self._tlwh = np.asarray(tlwh, dtype=np.float)
+        self._tlwh = np.asarray(tlwh, dtype=float)
         self.kalman_filter = None
         self.mean, self.covariance = None, None
         self.is_activated = False
